from cpython cimport bool

cdef list get_kmers_dicts(list seqs, unsigned int k, bool round_robin=?, unsigned int slider_increment=?)

cdef list get_kmers(str seq, unsigned int k, bool round_robin=?, unsigned int slider_increment=?)



from cpython cimport bool

cdef unsigned int hamming_distance(str seq1, str seq2, unsigned int limit=?)

cdef list subglobal_distance(str, str)

cdef unsigned int levenshtein_distance(str seq1, str seq2, unsigned int limit=?)
